# This is an example of how to use the Precision Analysis Class
from PrecisionAnalysis import PrecisionAnalysis
from UtilsRPE.Functions import load_vault
import pickle as pkl

# These are the parameters that are needed to launch a precision analysis experiment

experiment_name = "Perturbed_initial_state_analysis"

# Hostname of the remote machine that will be used to launch the simulations
remote_hostname = "mn2.bsc.es"

# Username used in the remote machine
remote_user = "bsc32402"

# Path to the folder where the simulations will be launched
remote_scratch = "/gpfs/scratch/bsc32/bsc32402/NEMO_MIXED_PERT_ANALYSIS"

# Path to the simulation template.
job_template = "SimulationTemplates/example.sh"

# Path to the vault
vault_path = "/home/Earth/sparonuz/Documents/Codes/recipes-for-AutoRPE/Remote/Files/vault.pkl"

vault = load_vault(vault_path)

# Dictionary containing the upper and lower thresholds that we don't want our final set to overcome.
limit_file = ""

# Target reduced precision level
reduced_precision_level = 23

# Maximum number of simultaneously running jobs
max_running_jobs = 100

# In case restarting a experiment from a checkpoint
restarting_from_checkpoint = False

# Dictionary containing the variables and the values of the thresholds that we don't want our final set to overcome.
error_thresholds = {"votemper": 0.0007167909394343306,
                    "vozocrtx": 7.003275906953925e-07,
                    "vomecrty": 6.99310434885036e-07,
                    "sohefldo": 0.00885575338581615,
                    "sozotaux": 1.0108048009931158e-06,
                    "sometauy": 1.1480837664543964e-06}

# Exclude previously identified variables

excluded_variables = []

analysis_variables = [v.id for v in vault.variables if v.id is not None]
analysis_variables = [v for v in analysis_variables if v not in excluded_variables]

# Create experiment object

experiment = PrecisionAnalysis(remote_hostname=remote_hostname, remote_user=remote_user, remote_scratch=remote_scratch,
                               job_template=job_template, vault=vault, error_thresholds=error_thresholds,
                               reduced_precision_level=reduced_precision_level, max_running_jobs=max_running_jobs,
                               experiment_name=experiment_name, restarting_from_checkpoint=restarting_from_checkpoint,
                               assertion_template=None)
# Launch experiment
experiment.run()

# The experiment will create a file named EXPERIMENT_NAME_final_set.pkl
