#!/bin/bash
###############################################################################
#                             SBATCH HEADER TEMPLATE
###############################################################################
#SBATCH --ntasks 96
#SBATCH -J %JOBNAME%
#SBATCH --output %LOGDIR%/log_%j.out
#SBATCH --error  %LOGDIR%/log_%j.err
#SBATCH --time 00:20:00
#SBATCH --qos=debug

set -xuve

JOB_ID=${SLURM_JOB_ID:-$LSB_JOBID}


# The rundir path will be replaced by the scheduler
RUN_dir=%RUNDIR%


# =============================================================================
# *** END of User configuration
# =============================================================================

set -xuve

if [[ -d $RUN_dir ]]; then
   rm -rf $RUN_dir
fi

mkdir -p $RUN_dir

cd $RUN_dir

echo ${JOB_ID} > job_id.txt



reference_state=/gpfs/scratch/bsc32/bsc32402/NEMO_MIXED_ANALYSIS/prec_52/RefinementTest11909856647413680226/initial_state_52.nc
nemo_bin=nemo

# Linking all files in the the inidata folder
INIDATA_PATH=/gpfs/scratch/bsc32/bsc32402/INPUT/MIXED_PREC_ORCA2_OCE_INPUT
ln -sf ${INIDATA_PATH}/* .


# The namelist path will be replaced by the scheduler
namelist=%NAMELIST_PATH%
if [ ! -f $namelist ] ;  then
     echo "namelist does not exist fort this case"
else
   cp $namelist --remove-destination namelist_precisions

   ls -lrt *


######################################################
#     SIMULATION::

# Load environment
environment_file=/gpfs/home/bsc32/bsc32402/bin/run_nemo/utilities/modules/modules_AutoRPE.env
set +xuve
source ${environment_file}
set -xuve

# Prepare initial conditions
# Create restart with perturbations
time mpirun -n 96 ./${nemo_bin}

# Remove restarts
   rm -f ORCA2_????????_restart_????.nc
   rm -f mesh_mask_????.nc
fi

#rebuild the state from files
/gpfs/home/bsc32/bsc32402/local/Nemo/release-4.0.1_r11711_autoRPE-OCE/tools/REBUILD/rebuild -o intial_state.nc output.init_00*

#compute the mean square error between state in double prec and  initial state
module load mkl
module load python/3.6.1
python3 RMSE.py ${reference_state} ./intial_state.nc  > accuracy.txt
#printf "var 0\n" > accuracy.txt

set +xuve
exit 0
